# special-octo-bassoon
Import a lospec palette into aseprite, personal use, feel free to read and modify this for your own needs

## How to use
`# import.py [url to 32x.png palette file from lospec]`
